@@ -14,8 +14,8 @@ import traceback
 import uuid
 from collections import defaultdict
 from functools import wraps
-
-import azure.cli.core.decorators as decorators
+from knack.util import CLIError
+from azure.cli.core import decorators
 
 PRODUCT_NAME = 'azurecli'
 TELEMETRY_VERSION = '0.0.1.4'
@@ -45,6 +45,7 @@ class TelemetrySession:  # pylint: disable=too-many-instance-attributes
         self.module_correlation = None
         self.extension_name = None
         self.extension_version = None
+        self.event_id = str(uuid.uuid4())
         self.feedback = None
         self.extension_management_detail = None
         self.raw_command = None
@@ -53,8 +54,6 @@ class TelemetrySession:  # pylint: disable=too-many-instance-attributes
         self.error_type = 'None'
         # The class name of the raw exception
         self.exception_name = 'None'
-        # The stacktrace of the raw exception
-        self.stack_trace = 'None'
         self.init_time_elapsed = None
         self.invoke_time_elapsed = None
         self.debug_info = []
@@ -64,12 +63,12 @@ class TelemetrySession:  # pylint: disable=too-many-instance-attributes
         # stops generate_payload() from adding new azurecli/command event
         # used for interactive to send new custom event upon exit
         self.suppress_new_event = False
+        self.poll_start_time = None
+        self.poll_end_time = None
 
     def add_exception(self, exception, fault_type, description=None, message=''):
         # Move the exception info into userTask record, in order to make one Telemetry record for one command
         self.exception_name = exception.__class__.__name__
-        self.result_summary = _remove_cmd_chars(message or str(exception))
-        self.stack_trace = _remove_cmd_chars(_get_stack_trace())
 
         # Backward compatible, so there are duplicated info recorded
         # The logic below should be removed along with self.exceptions after confirmation
@@ -81,7 +80,6 @@ class TelemetrySession:  # pylint: disable=too-many-instance-attributes
             'Reserved.DataModel.Fault.TypeString': exception.__class__.__name__,
             'Reserved.DataModel.Fault.Exception.Message': _remove_cmd_chars(
                 message or str(exception)),
-            'Reserved.DataModel.Fault.Exception.StackTrace': _remove_cmd_chars(_get_stack_trace()),
             AZURE_CLI_PREFIX + 'FaultType': fault_type.lower()
         }
 
@@ -108,7 +106,7 @@ class TelemetrySession:  # pylint: disable=too-many-instance-attributes
                 props.update(base)
                 props.update(cli)
                 props.update({CORRELATION_ID_PROP_NAME: str(uuid.uuid4()),
-                              'Reserved.EventId': str(uuid.uuid4())})
+                              'Reserved.EventId': self.event_id})
                 self.events[DEFAULT_INSTRUMENTATION_KEY].append({
                     'name': name,
                     'properties': props
@@ -120,7 +118,7 @@ class TelemetrySession:  # pylint: disable=too-many-instance-attributes
     def _get_base_properties(self):
         return {
             'Reserved.ChannelUsed': 'AI',
-            'Reserved.EventId': str(uuid.uuid4()),
+            'Reserved.EventId': self.event_id,
             'Reserved.SequenceNumber': 1,
             'Reserved.SessionId': _get_session_id(),
             'Reserved.TimeSinceSessionStart': 0,
@@ -200,8 +198,9 @@ class TelemetrySession:  # pylint: disable=too-many-instance-attributes
         set_custom_properties(result, 'Installer', os.getenv(_ENV_AZ_INSTALLER))
         set_custom_properties(result, 'error_type', self.error_type)
         set_custom_properties(result, 'exception_name', self.exception_name)
-        set_custom_properties(result, 'stack_trace', self.stack_trace)
         set_custom_properties(result, 'debug_info', ','.join(self.debug_info))
+        set_custom_properties(result, 'PollStartTime', str(self.poll_start_time))
+        set_custom_properties(result, 'PollEndTime', str(self.poll_end_time))
 
         return result
 
@@ -264,6 +263,16 @@ def set_invoke_time_elapsed(invoke_time_elapsed):
     _session.invoke_time_elapsed = invoke_time_elapsed
 
 
+@decorators.suppress_all_exceptions()
+def poll_start():
+    _session.poll_start_time = datetime.datetime.utcnow()
+
+
+@decorators.suppress_all_exceptions()
+def poll_end():
+    _session.poll_end_time = datetime.datetime.utcnow()
+
+
 @_user_agrees_to_telemetry
 @decorators.suppress_all_exceptions()
 def flush():
@@ -519,7 +528,10 @@ def _get_hash_machine_id():
 @decorators.suppress_all_exceptions(fallback_return='')
 @decorators.hash256_result
 def _get_user_azure_id():
-    return _get_profile().get_current_account_user()
+    try:
+        return _get_profile().get_current_account_user()
+    except CLIError:
+        return ''
 
 
 def _get_env_string():
@@ -529,7 +541,10 @@ def _get_env_string():
 
 @decorators.suppress_all_exceptions(fallback_return=None)
 def _get_azure_subscription_id():
-    return _get_profile().get_subscription_id()
+    try:
+        return _get_profile().get_subscription_id()
+    except CLIError:
+        return None
 
 
 def _get_shell_type():
